pub struct VerificationReport {
pub findings: Vec<DriftFinding>,
pub operations: Vec<Operation>,
pub pending_migrations: Vec<String>,
}Expand description
Result of comparing replayed migration state with inspected database state.
Fields
findings: Vec<DriftFinding>Property and presence differences found in migration-owned entities.
operations: Vec<Operation>Coarse repair operations that can restore registered expected state.
pending_migrations: Vec<String>Migration ids that must normally be applied before drift can be repaired.