Operation

Enum Operation 

pub enum Operation {
Show 30 variants CreateTable { table: Table, }, DropTable { table: Table, }, RenameTable { old_name: String, new_name: String, }, AcknowledgeTableOptions { table_name: String, old: TableOptionsMeta, new: TableOptionsMeta, }, AddColumn { table_name: String, column: Column, }, DropColumn { table_name: String, column: Column, cascade: bool, }, RenameColumn { table_name: String, old_name: String, new_name: String, }, AlterColumn { table_name: String, old: Column, new: Column, cast_expr: Option<String>, }, AddForeignKey { table_name: String, foreign_key: ForeignKey, }, DropForeignKey { table_name: String, foreign_key: ForeignKey, cascade: bool, }, AddIndex { table_name: String, index: Index, concurrent: bool, }, DropIndex { table_name: String, index: Index, concurrent: bool, }, AddConstraint { table_name: String, constraint: Constraint, }, DropConstraint { table_name: String, constraint: Constraint, }, Statement { up: String, down: Option<String>, }, CreateFunction { function: FunctionDef, }, AlterFunction { old: FunctionDef, new: FunctionDef, }, DropFunction { function: FunctionDef, }, CreateTrigger { table_name: String, trigger: TriggerDef, }, AlterTrigger { table_name: String, old: TriggerDef, new: TriggerDef, }, DropTrigger { table_name: String, trigger: TriggerDef, }, CreateView { view: ViewDef, }, DropView { view: ViewDef, }, ReplaceView { old: ViewDef, new: ViewDef, }, CreateExtension { extension: ExtensionDef, }, DropExtension { extension: ExtensionDef, }, CreateEnum { enum_def: EnumDef, }, DropEnum { enum_def: EnumDef, }, RenameEnumValue { enum_name: String, schema: Option<String>, old_value: String, new_value: String, }, AlterEnum { old: EnumDef, new: EnumDef, },
}
All possible schema change operations. Each variant carries the minimal data needed to describe the change.

Variants



CreateTable

Fields

table: Table


DropTable

Fields

table: Table


RenameTable

Fields

old_name: String
new_name: String


AcknowledgeTableOptions

Fields

table_name: String
old: TableOptionsMeta
new: TableOptionsMeta


AddColumn

Fields

table_name: String
column: Column


DropColumn

Fields

table_name: String
column: Column
cascade: bool


RenameColumn

Fields

table_name: String
old_name: String
new_name: String


AlterColumn

Fields

table_name: String
cast_expr: Option<String>


AddForeignKey

Fields

table_name: String
foreign_key: ForeignKey


DropForeignKey

Fields

table_name: String
foreign_key: ForeignKey
cascade: bool


AddIndex

Fields

table_name: String
index: Index
concurrent: bool


DropIndex

Fields

table_name: String
index: Index
concurrent: bool


AddConstraint

Fields

table_name: String
constraint: Constraint


DropConstraint

Fields

table_name: String
constraint: Constraint


Statement

Fields



CreateFunction

Fields

function: FunctionDef


AlterFunction



DropFunction

Fields

function: FunctionDef


CreateTrigger

Fields

table_name: String
trigger: TriggerDef


AlterTrigger

Fields

table_name: String


DropTrigger

Fields

table_name: String
trigger: TriggerDef


CreateView

Fields

view: ViewDef


DropView

Fields

view: ViewDef


ReplaceView

Fields



CreateExtension

Fields

extension: ExtensionDef


DropExtension

Fields

extension: ExtensionDef


CreateEnum

Fields

enum_def: EnumDef


DropEnum

Fields

enum_def: EnumDef


RenameEnumValue

Fields

enum_name: String
schema: Option<String>
old_value: String
new_value: String


AlterEnum

Fields

Implementations

Source

impl Operation

pub fn inverse(&self) -> Option<Operation>

pub fn table_name(&self) -> Option<&str>

pub fn entity_name(&self) -> Cow<'_, str>

pub fn type_name(&self) -> &'static str

pub fn entity_kind(&self) -> Option<EntityKind>

pub fn is_create(&self) -> bool

pub fn is_drop(&self) -> bool

pub fn forward_deps(&self) -> Vec<Dep>

pub fn backward_deps(&self) -> Vec<Dep>

pub fn entity_label(&self) -> Option<&str>

Returns the primary entity label used for deterministic migration names.

pub fn touched_entities(&self) -> Vec<(EntityKind, String)>

Returns the stable entity identities touched by this operation.